#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'appearancesettings.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_APPEARANCESETTINGS_H
#define UI_APPEARANCESETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_AppearanceSettings
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox_1;
    QVBoxLayout *verticalLayout_1;
    QCheckBox *kcfg_TerminalHighlightOnManualActivation;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *backgroundColorLabel;
    KColorButton *kcfg_BackgroundColor;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_Translucency;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *spacer;
    QLabel *backgroundColorOpacityLabel;
    QSpinBox *kcfg_BackgroundColorOpacity;
    QSpacerItem *spacer_2;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout;
    QPushButton *ghnsButton;
    QListView *skinList;
    QLineEdit *kcfg_Skin;
    QPushButton *removeButton;
    QPushButton *installButton;
    QCheckBox *kcfg_SkinInstalledWithKns;

    void setupUi(QWidget *AppearanceSettings)
    {
        if (AppearanceSettings->objectName().isEmpty())
            AppearanceSettings->setObjectName(QStringLiteral("AppearanceSettings"));
        AppearanceSettings->resize(713, 909);
        verticalLayout_3 = new QVBoxLayout(AppearanceSettings);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        groupBox_1 = new QGroupBox(AppearanceSettings);
        groupBox_1->setObjectName(QStringLiteral("groupBox_1"));
        verticalLayout_1 = new QVBoxLayout(groupBox_1);
        verticalLayout_1->setObjectName(QStringLiteral("verticalLayout_1"));
        kcfg_TerminalHighlightOnManualActivation = new QCheckBox(groupBox_1);
        kcfg_TerminalHighlightOnManualActivation->setObjectName(QStringLiteral("kcfg_TerminalHighlightOnManualActivation"));

        verticalLayout_1->addWidget(kcfg_TerminalHighlightOnManualActivation);


        verticalLayout_3->addWidget(groupBox_1);

        groupBox_2 = new QGroupBox(AppearanceSettings);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        backgroundColorLabel = new QLabel(groupBox_2);
        backgroundColorLabel->setObjectName(QStringLiteral("backgroundColorLabel"));

        hboxLayout->addWidget(backgroundColorLabel);

        kcfg_BackgroundColor = new KColorButton(groupBox_2);
        kcfg_BackgroundColor->setObjectName(QStringLiteral("kcfg_BackgroundColor"));

        hboxLayout->addWidget(kcfg_BackgroundColor);

        spacerItem = new QSpacerItem(41, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        verticalLayout_2->addLayout(hboxLayout);

        kcfg_Translucency = new QCheckBox(groupBox_2);
        kcfg_Translucency->setObjectName(QStringLiteral("kcfg_Translucency"));

        verticalLayout_2->addWidget(kcfg_Translucency);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        horizontalLayout->setContentsMargins(7, -1, -1, -1);
        spacer = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacer);

        backgroundColorOpacityLabel = new QLabel(groupBox_2);
        backgroundColorOpacityLabel->setObjectName(QStringLiteral("backgroundColorOpacityLabel"));
        backgroundColorOpacityLabel->setEnabled(false);

        horizontalLayout->addWidget(backgroundColorOpacityLabel);

        kcfg_BackgroundColorOpacity = new QSpinBox(groupBox_2);
        kcfg_BackgroundColorOpacity->setObjectName(QStringLiteral("kcfg_BackgroundColorOpacity"));
        kcfg_BackgroundColorOpacity->setEnabled(false);
        kcfg_BackgroundColorOpacity->setMaximum(100);
        kcfg_BackgroundColorOpacity->setValue(50);

        horizontalLayout->addWidget(kcfg_BackgroundColorOpacity);

        spacer_2 = new QSpacerItem(64, 17, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(spacer_2);


        verticalLayout_2->addLayout(horizontalLayout);


        verticalLayout_3->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(AppearanceSettings);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        gridLayout = new QGridLayout(groupBox_3);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        ghnsButton = new QPushButton(groupBox_3);
        ghnsButton->setObjectName(QStringLiteral("ghnsButton"));

        gridLayout->addWidget(ghnsButton, 2, 0, 1, 2);

        skinList = new QListView(groupBox_3);
        skinList->setObjectName(QStringLiteral("skinList"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(skinList->sizePolicy().hasHeightForWidth());
        skinList->setSizePolicy(sizePolicy);
        skinList->setContextMenuPolicy(Qt::NoContextMenu);
        skinList->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

        gridLayout->addWidget(skinList, 0, 0, 1, 2);

        kcfg_Skin = new QLineEdit(groupBox_3);
        kcfg_Skin->setObjectName(QStringLiteral("kcfg_Skin"));
        kcfg_Skin->setFrame(false);

        gridLayout->addWidget(kcfg_Skin, 3, 0, 1, 2);

        removeButton = new QPushButton(groupBox_3);
        removeButton->setObjectName(QStringLiteral("removeButton"));
        removeButton->setEnabled(false);

        gridLayout->addWidget(removeButton, 1, 1, 1, 1);

        installButton = new QPushButton(groupBox_3);
        installButton->setObjectName(QStringLiteral("installButton"));
        installButton->setEnabled(true);

        gridLayout->addWidget(installButton, 1, 0, 1, 1);

        kcfg_SkinInstalledWithKns = new QCheckBox(groupBox_3);
        kcfg_SkinInstalledWithKns->setObjectName(QStringLiteral("kcfg_SkinInstalledWithKns"));

        gridLayout->addWidget(kcfg_SkinInstalledWithKns, 4, 0, 1, 1);


        verticalLayout_3->addWidget(groupBox_3);

        QWidget::setTabOrder(kcfg_TerminalHighlightOnManualActivation, kcfg_BackgroundColor);
        QWidget::setTabOrder(kcfg_BackgroundColor, kcfg_Translucency);
        QWidget::setTabOrder(kcfg_Translucency, kcfg_BackgroundColorOpacity);
        QWidget::setTabOrder(kcfg_BackgroundColorOpacity, skinList);
        QWidget::setTabOrder(skinList, installButton);
        QWidget::setTabOrder(installButton, removeButton);
        QWidget::setTabOrder(removeButton, ghnsButton);
        QWidget::setTabOrder(ghnsButton, kcfg_Skin);
        QWidget::setTabOrder(kcfg_Skin, kcfg_SkinInstalledWithKns);

        retranslateUi(AppearanceSettings);
        QObject::connect(kcfg_Translucency, SIGNAL(toggled(bool)), kcfg_BackgroundColorOpacity, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_Translucency, SIGNAL(toggled(bool)), backgroundColorOpacityLabel, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(AppearanceSettings);
    } // setupUi

    void retranslateUi(QWidget *AppearanceSettings)
    {
        groupBox_1->setTitle(tr2i18n("General", "@title:group Group box label"));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_TerminalHighlightOnManualActivation->setWhatsThis(tr2i18n("Enabling this option will make Yakuake briefly display a colored overlay above the newly focused terminal when moving focus between multple terminals in a session, as well as over the currently focused terminal when switching to a session with multiple terminals.", "@info:whatsthis"));
#endif // QT_NO_WHATSTHIS
        kcfg_TerminalHighlightOnManualActivation->setText(tr2i18n("Highlight terminals when moving focus between them", "@option:check"));
        groupBox_2->setTitle(tr2i18n("Window Background", "@title:group"));
        backgroundColorLabel->setText(tr2i18n("Background color:", "@label:chooser"));
        kcfg_BackgroundColor->setText(QString());
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_Translucency->setWhatsThis(tr2i18n("Translucency requires support by the selected skin as well as your desktop environment. The default skin supports translucency.", "@info:whatsthis"));
#endif // QT_NO_WHATSTHIS
        kcfg_Translucency->setText(tr2i18n("Use skin translucency if supported", "@option:check"));
        backgroundColorOpacityLabel->setText(tr2i18n("Background color opacity:", "@label:spinbox"));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_BackgroundColorOpacity->setWhatsThis(tr2i18n("When using translucency, the background color will be filled in using the given opacity before the skin elements are painted on top of the background. This allows influencing the opacity and color tint of translucent areas of the skin.", "@info:whatsthis"));
#endif // QT_NO_WHATSTHIS
        kcfg_BackgroundColorOpacity->setSuffix(tr2i18n("%", "@label Spinbox unit suffix"));
        groupBox_3->setTitle(tr2i18n("Skin", "@title:group"));
        ghnsButton->setText(tr2i18n("Get New Skins...", "@action:button"));
        removeButton->setText(tr2i18n("Remove Skin", "@action:button"));
        installButton->setText(tr2i18n("Install Skin...", "@action:button"));
        kcfg_SkinInstalledWithKns->setText(QString());
        Q_UNUSED(AppearanceSettings);
    } // retranslateUi

};

namespace Ui {
    class AppearanceSettings: public Ui_AppearanceSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // APPEARANCESETTINGS_H

