/****************************************************************************
** Meta object code from reading C++ file 'sessionstack.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/yakuake-3.0.2/app/sessionstack.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sessionstack.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_SessionStack_t {
    QByteArrayData data[71];
    char stringdata0[1469];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SessionStack_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SessionStack_t qt_meta_stringdata_SessionStack = {
    {
QT_MOC_LITERAL(0, 0, 12), // "SessionStack"
QT_MOC_LITERAL(1, 13, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 29, 15), // "org.kde.yakuake"
QT_MOC_LITERAL(3, 45, 12), // "sessionAdded"
QT_MOC_LITERAL(4, 58, 0), // ""
QT_MOC_LITERAL(5, 59, 9), // "sessionId"
QT_MOC_LITERAL(6, 69, 5), // "title"
QT_MOC_LITERAL(7, 75, 13), // "sessionRaised"
QT_MOC_LITERAL(8, 89, 14), // "sessionRemoved"
QT_MOC_LITERAL(9, 104, 18), // "activeTitleChanged"
QT_MOC_LITERAL(10, 123, 12), // "titleChanged"
QT_MOC_LITERAL(11, 136, 13), // "closeTerminal"
QT_MOC_LITERAL(12, 150, 16), // "previousTerminal"
QT_MOC_LITERAL(13, 167, 12), // "nextTerminal"
QT_MOC_LITERAL(14, 180, 14), // "manageProfiles"
QT_MOC_LITERAL(15, 195, 23), // "removeTerminalHighlight"
QT_MOC_LITERAL(16, 219, 10), // "addSession"
QT_MOC_LITERAL(17, 230, 20), // "Session::SessionType"
QT_MOC_LITERAL(18, 251, 4), // "type"
QT_MOC_LITERAL(19, 256, 23), // "addSessionTwoHorizontal"
QT_MOC_LITERAL(20, 280, 21), // "addSessionTwoVertical"
QT_MOC_LITERAL(21, 302, 14), // "addSessionQuad"
QT_MOC_LITERAL(22, 317, 12), // "raiseSession"
QT_MOC_LITERAL(23, 330, 13), // "removeSession"
QT_MOC_LITERAL(24, 344, 14), // "removeTerminal"
QT_MOC_LITERAL(25, 359, 10), // "terminalId"
QT_MOC_LITERAL(26, 370, 21), // "splitSessionLeftRight"
QT_MOC_LITERAL(27, 392, 21), // "splitSessionTopBottom"
QT_MOC_LITERAL(28, 414, 22), // "splitTerminalLeftRight"
QT_MOC_LITERAL(29, 437, 22), // "splitTerminalTopBottom"
QT_MOC_LITERAL(30, 460, 20), // "tryGrowTerminalRight"
QT_MOC_LITERAL(31, 481, 6), // "pixels"
QT_MOC_LITERAL(32, 488, 19), // "tryGrowTerminalLeft"
QT_MOC_LITERAL(33, 508, 18), // "tryGrowTerminalTop"
QT_MOC_LITERAL(34, 527, 21), // "tryGrowTerminalBottom"
QT_MOC_LITERAL(35, 549, 15), // "activeSessionId"
QT_MOC_LITERAL(36, 565, 16), // "activeTerminalId"
QT_MOC_LITERAL(37, 582, 13), // "sessionIdList"
QT_MOC_LITERAL(38, 596, 14), // "terminalIdList"
QT_MOC_LITERAL(39, 611, 23), // "terminalIdsForSessionId"
QT_MOC_LITERAL(40, 635, 22), // "sessionIdForTerminalId"
QT_MOC_LITERAL(41, 658, 10), // "runCommand"
QT_MOC_LITERAL(42, 669, 7), // "command"
QT_MOC_LITERAL(43, 677, 20), // "runCommandInTerminal"
QT_MOC_LITERAL(44, 698, 17), // "isSessionClosable"
QT_MOC_LITERAL(45, 716, 18), // "setSessionClosable"
QT_MOC_LITERAL(46, 735, 8), // "closable"
QT_MOC_LITERAL(47, 744, 21), // "hasUnclosableSessions"
QT_MOC_LITERAL(48, 766, 29), // "isSessionKeyboardInputEnabled"
QT_MOC_LITERAL(49, 796, 30), // "setSessionKeyboardInputEnabled"
QT_MOC_LITERAL(50, 827, 7), // "enabled"
QT_MOC_LITERAL(51, 835, 30), // "isTerminalKeyboardInputEnabled"
QT_MOC_LITERAL(52, 866, 31), // "setTerminalKeyboardInputEnabled"
QT_MOC_LITERAL(53, 898, 36), // "hasTerminalsWithKeyboardInput..."
QT_MOC_LITERAL(54, 935, 37), // "hasTerminalsWithKeyboardInput..."
QT_MOC_LITERAL(55, 973, 31), // "isSessionMonitorActivityEnabled"
QT_MOC_LITERAL(56, 1005, 32), // "setSessionMonitorActivityEnabled"
QT_MOC_LITERAL(57, 1038, 32), // "isTerminalMonitorActivityEnabled"
QT_MOC_LITERAL(58, 1071, 33), // "setTerminalMonitorActivityEna..."
QT_MOC_LITERAL(59, 1105, 38), // "hasTerminalsWithMonitorActivi..."
QT_MOC_LITERAL(60, 1144, 39), // "hasTerminalsWithMonitorActivi..."
QT_MOC_LITERAL(61, 1184, 30), // "isSessionMonitorSilenceEnabled"
QT_MOC_LITERAL(62, 1215, 31), // "setSessionMonitorSilenceEnabled"
QT_MOC_LITERAL(63, 1247, 31), // "isTerminalMonitorSilenceEnabled"
QT_MOC_LITERAL(64, 1279, 32), // "setTerminalMonitorSilenceEnabled"
QT_MOC_LITERAL(65, 1312, 37), // "hasTerminalsWithMonitorSilenc..."
QT_MOC_LITERAL(66, 1350, 38), // "hasTerminalsWithMonitorSilenc..."
QT_MOC_LITERAL(67, 1389, 30), // "handleTerminalHighlightRequest"
QT_MOC_LITERAL(68, 1420, 30), // "handleManualTerminalActivation"
QT_MOC_LITERAL(69, 1451, 9), // "Terminal*"
QT_MOC_LITERAL(70, 1461, 7) // "cleanup"

    },
    "SessionStack\0D-Bus Interface\0"
    "org.kde.yakuake\0sessionAdded\0\0sessionId\0"
    "title\0sessionRaised\0sessionRemoved\0"
    "activeTitleChanged\0titleChanged\0"
    "closeTerminal\0previousTerminal\0"
    "nextTerminal\0manageProfiles\0"
    "removeTerminalHighlight\0addSession\0"
    "Session::SessionType\0type\0"
    "addSessionTwoHorizontal\0addSessionTwoVertical\0"
    "addSessionQuad\0raiseSession\0removeSession\0"
    "removeTerminal\0terminalId\0"
    "splitSessionLeftRight\0splitSessionTopBottom\0"
    "splitTerminalLeftRight\0splitTerminalTopBottom\0"
    "tryGrowTerminalRight\0pixels\0"
    "tryGrowTerminalLeft\0tryGrowTerminalTop\0"
    "tryGrowTerminalBottom\0activeSessionId\0"
    "activeTerminalId\0sessionIdList\0"
    "terminalIdList\0terminalIdsForSessionId\0"
    "sessionIdForTerminalId\0runCommand\0"
    "command\0runCommandInTerminal\0"
    "isSessionClosable\0setSessionClosable\0"
    "closable\0hasUnclosableSessions\0"
    "isSessionKeyboardInputEnabled\0"
    "setSessionKeyboardInputEnabled\0enabled\0"
    "isTerminalKeyboardInputEnabled\0"
    "setTerminalKeyboardInputEnabled\0"
    "hasTerminalsWithKeyboardInputEnabled\0"
    "hasTerminalsWithKeyboardInputDisabled\0"
    "isSessionMonitorActivityEnabled\0"
    "setSessionMonitorActivityEnabled\0"
    "isTerminalMonitorActivityEnabled\0"
    "setTerminalMonitorActivityEnabled\0"
    "hasTerminalsWithMonitorActivityEnabled\0"
    "hasTerminalsWithMonitorActivityDisabled\0"
    "isSessionMonitorSilenceEnabled\0"
    "setSessionMonitorSilenceEnabled\0"
    "isTerminalMonitorSilenceEnabled\0"
    "setTerminalMonitorSilenceEnabled\0"
    "hasTerminalsWithMonitorSilenceEnabled\0"
    "hasTerminalsWithMonitorSilenceDisabled\0"
    "handleTerminalHighlightRequest\0"
    "handleManualTerminalActivation\0Terminal*\0"
    "cleanup"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SessionStack[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      62,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    2,  326,    4, 0x06 /* Public */,
       7,    1,  331,    4, 0x06 /* Public */,
       8,    1,  334,    4, 0x06 /* Public */,
       9,    1,  337,    4, 0x06 /* Public */,
      10,    2,  340,    4, 0x06 /* Public */,
      11,    0,  345,    4, 0x06 /* Public */,
      12,    0,  346,    4, 0x06 /* Public */,
      13,    0,  347,    4, 0x06 /* Public */,
      14,    0,  348,    4, 0x06 /* Public */,
      15,    0,  349,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      16,    1,  350,    4, 0x4a /* Public | isScriptable */,
      16,    0,  353,    4, 0x6a /* Public | MethodCloned | isScriptable */,
      19,    0,  354,    4, 0x4a /* Public | isScriptable */,
      20,    0,  355,    4, 0x4a /* Public | isScriptable */,
      21,    0,  356,    4, 0x4a /* Public | isScriptable */,
      22,    1,  357,    4, 0x4a /* Public | isScriptable */,
      23,    1,  360,    4, 0x4a /* Public | isScriptable */,
      24,    1,  363,    4, 0x4a /* Public | isScriptable */,
      26,    1,  366,    4, 0x4a /* Public | isScriptable */,
      27,    1,  369,    4, 0x4a /* Public | isScriptable */,
      28,    1,  372,    4, 0x4a /* Public | isScriptable */,
      29,    1,  375,    4, 0x4a /* Public | isScriptable */,
      30,    2,  378,    4, 0x4a /* Public | isScriptable */,
      30,    1,  383,    4, 0x6a /* Public | MethodCloned | isScriptable */,
      32,    2,  386,    4, 0x4a /* Public | isScriptable */,
      32,    1,  391,    4, 0x6a /* Public | MethodCloned | isScriptable */,
      33,    2,  394,    4, 0x4a /* Public | isScriptable */,
      33,    1,  399,    4, 0x6a /* Public | MethodCloned | isScriptable */,
      34,    2,  402,    4, 0x4a /* Public | isScriptable */,
      34,    1,  407,    4, 0x6a /* Public | MethodCloned | isScriptable */,
      35,    0,  410,    4, 0x4a /* Public | isScriptable */,
      36,    0,  411,    4, 0x4a /* Public | isScriptable */,
      37,    0,  412,    4, 0x4a /* Public | isScriptable */,
      38,    0,  413,    4, 0x4a /* Public | isScriptable */,
      39,    1,  414,    4, 0x4a /* Public | isScriptable */,
      40,    1,  417,    4, 0x4a /* Public | isScriptable */,
      41,    1,  420,    4, 0x4a /* Public | isScriptable */,
      43,    2,  423,    4, 0x4a /* Public | isScriptable */,
      44,    1,  428,    4, 0x4a /* Public | isScriptable */,
      45,    2,  431,    4, 0x4a /* Public | isScriptable */,
      47,    0,  436,    4, 0x4a /* Public | isScriptable */,
      48,    1,  437,    4, 0x4a /* Public | isScriptable */,
      49,    2,  440,    4, 0x4a /* Public | isScriptable */,
      51,    1,  445,    4, 0x4a /* Public | isScriptable */,
      52,    2,  448,    4, 0x4a /* Public | isScriptable */,
      53,    1,  453,    4, 0x4a /* Public | isScriptable */,
      54,    1,  456,    4, 0x4a /* Public | isScriptable */,
      55,    1,  459,    4, 0x4a /* Public | isScriptable */,
      56,    2,  462,    4, 0x4a /* Public | isScriptable */,
      57,    1,  467,    4, 0x4a /* Public | isScriptable */,
      58,    2,  470,    4, 0x4a /* Public | isScriptable */,
      59,    1,  475,    4, 0x4a /* Public | isScriptable */,
      60,    1,  478,    4, 0x4a /* Public | isScriptable */,
      61,    1,  481,    4, 0x4a /* Public | isScriptable */,
      62,    2,  484,    4, 0x4a /* Public | isScriptable */,
      63,    1,  489,    4, 0x4a /* Public | isScriptable */,
      64,    2,  492,    4, 0x4a /* Public | isScriptable */,
      65,    1,  497,    4, 0x4a /* Public | isScriptable */,
      66,    1,  500,    4, 0x4a /* Public | isScriptable */,
      67,    1,  503,    4, 0x0a /* Public */,
      68,    1,  506,    4, 0x08 /* Private */,
      70,    1,  509,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    5,    6,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Int, 0x80000000 | 17,   18,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Int, QMetaType::Int,    5,
    QMetaType::Int, QMetaType::Int,    5,
    QMetaType::Int, QMetaType::Int,   25,
    QMetaType::Int, QMetaType::Int,   25,
    QMetaType::Int, QMetaType::Int, QMetaType::UInt,   25,   31,
    QMetaType::Int, QMetaType::Int,   25,
    QMetaType::Int, QMetaType::Int, QMetaType::UInt,   25,   31,
    QMetaType::Int, QMetaType::Int,   25,
    QMetaType::Int, QMetaType::Int, QMetaType::UInt,   25,   31,
    QMetaType::Int, QMetaType::Int,   25,
    QMetaType::Int, QMetaType::Int, QMetaType::UInt,   25,   31,
    QMetaType::Int, QMetaType::Int,   25,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QString, QMetaType::Int,    5,
    QMetaType::Int, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::QString,   42,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   25,   42,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    5,   46,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    5,   50,
    QMetaType::Bool, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   25,   50,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    5,   50,
    QMetaType::Bool, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   25,   50,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    5,   50,
    QMetaType::Bool, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,   25,   50,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Bool, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void, 0x80000000 | 69,    4,
    QMetaType::Void, QMetaType::Int,    5,

       0        // eod
};

void SessionStack::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SessionStack *_t = static_cast<SessionStack *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->sessionAdded((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->sessionRaised((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->sessionRemoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->activeTitleChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->titleChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->closeTerminal(); break;
        case 6: _t->previousTerminal(); break;
        case 7: _t->nextTerminal(); break;
        case 8: _t->manageProfiles(); break;
        case 9: _t->removeTerminalHighlight(); break;
        case 10: { int _r = _t->addSession((*reinterpret_cast< Session::SessionType(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 11: { int _r = _t->addSession();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 12: { int _r = _t->addSessionTwoHorizontal();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 13: { int _r = _t->addSessionTwoVertical();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 14: { int _r = _t->addSessionQuad();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 15: _t->raiseSession((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->removeSession((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->removeTerminal((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: { int _r = _t->splitSessionLeftRight((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 19: { int _r = _t->splitSessionTopBottom((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 20: { int _r = _t->splitTerminalLeftRight((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 21: { int _r = _t->splitTerminalTopBottom((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 22: { int _r = _t->tryGrowTerminalRight((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 23: { int _r = _t->tryGrowTerminalRight((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 24: { int _r = _t->tryGrowTerminalLeft((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 25: { int _r = _t->tryGrowTerminalLeft((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 26: { int _r = _t->tryGrowTerminalTop((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 27: { int _r = _t->tryGrowTerminalTop((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 28: { int _r = _t->tryGrowTerminalBottom((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 29: { int _r = _t->tryGrowTerminalBottom((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 30: { int _r = _t->activeSessionId();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 31: { int _r = _t->activeTerminalId();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 32: { QString _r = _t->sessionIdList();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 33: { QString _r = _t->terminalIdList();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 34: { QString _r = _t->terminalIdsForSessionId((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 35: { int _r = _t->sessionIdForTerminalId((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 36: _t->runCommand((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 37: _t->runCommandInTerminal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 38: { bool _r = _t->isSessionClosable((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 39: _t->setSessionClosable((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 40: { bool _r = _t->hasUnclosableSessions();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 41: { bool _r = _t->isSessionKeyboardInputEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 42: _t->setSessionKeyboardInputEnabled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 43: { bool _r = _t->isTerminalKeyboardInputEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 44: _t->setTerminalKeyboardInputEnabled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 45: { bool _r = _t->hasTerminalsWithKeyboardInputEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 46: { bool _r = _t->hasTerminalsWithKeyboardInputDisabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 47: { bool _r = _t->isSessionMonitorActivityEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 48: _t->setSessionMonitorActivityEnabled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 49: { bool _r = _t->isTerminalMonitorActivityEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 50: _t->setTerminalMonitorActivityEnabled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 51: { bool _r = _t->hasTerminalsWithMonitorActivityEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 52: { bool _r = _t->hasTerminalsWithMonitorActivityDisabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 53: { bool _r = _t->isSessionMonitorSilenceEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 54: _t->setSessionMonitorSilenceEnabled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 55: { bool _r = _t->isTerminalMonitorSilenceEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 56: _t->setTerminalMonitorSilenceEnabled((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 57: { bool _r = _t->hasTerminalsWithMonitorSilenceEnabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 58: { bool _r = _t->hasTerminalsWithMonitorSilenceDisabled((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 59: _t->handleTerminalHighlightRequest((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 60: _t->handleManualTerminalActivation((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 61: _t->cleanup((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (SessionStack::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::sessionAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::sessionRaised)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::sessionRemoved)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::activeTitleChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::titleChanged)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::closeTerminal)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::previousTerminal)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::nextTerminal)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::manageProfiles)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (SessionStack::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&SessionStack::removeTerminalHighlight)) {
                *result = 9;
                return;
            }
        }
    }
}

const QMetaObject SessionStack::staticMetaObject = {
    { &QStackedWidget::staticMetaObject, qt_meta_stringdata_SessionStack.data,
      qt_meta_data_SessionStack,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *SessionStack::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SessionStack::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_SessionStack.stringdata0))
        return static_cast<void*>(const_cast< SessionStack*>(this));
    return QStackedWidget::qt_metacast(_clname);
}

int SessionStack::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStackedWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 62)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 62;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 62)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 62;
    }
    return _id;
}

// SIGNAL 0
void SessionStack::sessionAdded(int _t1, const QString & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void SessionStack::sessionRaised(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void SessionStack::sessionRemoved(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void SessionStack::activeTitleChanged(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void SessionStack::titleChanged(int _t1, const QString & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void SessionStack::closeTerminal()
{
    QMetaObject::activate(this, &staticMetaObject, 5, Q_NULLPTR);
}

// SIGNAL 6
void SessionStack::previousTerminal()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}

// SIGNAL 7
void SessionStack::nextTerminal()
{
    QMetaObject::activate(this, &staticMetaObject, 7, Q_NULLPTR);
}

// SIGNAL 8
void SessionStack::manageProfiles()
{
    QMetaObject::activate(this, &staticMetaObject, 8, Q_NULLPTR);
}

// SIGNAL 9
void SessionStack::removeTerminalHighlight()
{
    QMetaObject::activate(this, &staticMetaObject, 9, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
