#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'behaviorsettings.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BEHAVIORSETTINGS_H
#define UI_BEHAVIORSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BehaviorSettings
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_1;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_FocusFollowsMouse;
    QCheckBox *kcfg_ToggleToFocus;
    QCheckBox *kcfg_KeepAbove;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_OpenAfterStart;
    QCheckBox *kcfg_PollMouse;
    QCheckBox *kcfg_KeepOpen;
    QSpacerItem *spacerItem1;
    QCheckBox *kcfg_KeepOpenAfterLastSessionCloses;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_ConfirmQuit;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *BehaviorSettings)
    {
        if (BehaviorSettings->objectName().isEmpty())
            BehaviorSettings->setObjectName(QStringLiteral("BehaviorSettings"));
        BehaviorSettings->resize(356, 289);
        verticalLayout = new QVBoxLayout(BehaviorSettings);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        groupBox_1 = new QGroupBox(BehaviorSettings);
        groupBox_1->setObjectName(QStringLiteral("groupBox_1"));
        gridLayout = new QGridLayout(groupBox_1);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        kcfg_FocusFollowsMouse = new QCheckBox(groupBox_1);
        kcfg_FocusFollowsMouse->setObjectName(QStringLiteral("kcfg_FocusFollowsMouse"));

        gridLayout->addWidget(kcfg_FocusFollowsMouse, 6, 0, 1, 2);

        kcfg_ToggleToFocus = new QCheckBox(groupBox_1);
        kcfg_ToggleToFocus->setObjectName(QStringLiteral("kcfg_ToggleToFocus"));
        kcfg_ToggleToFocus->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_ToggleToFocus->sizePolicy().hasHeightForWidth());
        kcfg_ToggleToFocus->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_ToggleToFocus, 4, 1, 1, 1);

        kcfg_KeepAbove = new QCheckBox(groupBox_1);
        kcfg_KeepAbove->setObjectName(QStringLiteral("kcfg_KeepAbove"));
        kcfg_KeepAbove->setEnabled(false);
        sizePolicy.setHeightForWidth(kcfg_KeepAbove->sizePolicy().hasHeightForWidth());
        kcfg_KeepAbove->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_KeepAbove, 3, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 4, 0, 1, 1);

        kcfg_OpenAfterStart = new QCheckBox(groupBox_1);
        kcfg_OpenAfterStart->setObjectName(QStringLiteral("kcfg_OpenAfterStart"));

        gridLayout->addWidget(kcfg_OpenAfterStart, 0, 0, 1, 2);

        kcfg_PollMouse = new QCheckBox(groupBox_1);
        kcfg_PollMouse->setObjectName(QStringLiteral("kcfg_PollMouse"));

        gridLayout->addWidget(kcfg_PollMouse, 1, 0, 1, 2);

        kcfg_KeepOpen = new QCheckBox(groupBox_1);
        kcfg_KeepOpen->setObjectName(QStringLiteral("kcfg_KeepOpen"));

        gridLayout->addWidget(kcfg_KeepOpen, 2, 0, 1, 2);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 3, 0, 1, 1);

        kcfg_KeepOpenAfterLastSessionCloses = new QCheckBox(groupBox_1);
        kcfg_KeepOpenAfterLastSessionCloses->setObjectName(QStringLiteral("kcfg_KeepOpenAfterLastSessionCloses"));

        gridLayout->addWidget(kcfg_KeepOpenAfterLastSessionCloses, 5, 0, 1, 2);


        verticalLayout->addWidget(groupBox_1);

        groupBox_2 = new QGroupBox(BehaviorSettings);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        vboxLayout = new QVBoxLayout(groupBox_2);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        kcfg_ConfirmQuit = new QCheckBox(groupBox_2);
        kcfg_ConfirmQuit->setObjectName(QStringLiteral("kcfg_ConfirmQuit"));

        vboxLayout->addWidget(kcfg_ConfirmQuit);


        verticalLayout->addWidget(groupBox_2);

        spacerItem2 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem2);

        QWidget::setTabOrder(kcfg_OpenAfterStart, kcfg_PollMouse);
        QWidget::setTabOrder(kcfg_PollMouse, kcfg_KeepOpen);
        QWidget::setTabOrder(kcfg_KeepOpen, kcfg_KeepAbove);
        QWidget::setTabOrder(kcfg_KeepAbove, kcfg_ToggleToFocus);
        QWidget::setTabOrder(kcfg_ToggleToFocus, kcfg_KeepOpenAfterLastSessionCloses);
        QWidget::setTabOrder(kcfg_KeepOpenAfterLastSessionCloses, kcfg_FocusFollowsMouse);
        QWidget::setTabOrder(kcfg_FocusFollowsMouse, kcfg_ConfirmQuit);

        retranslateUi(BehaviorSettings);
        QObject::connect(kcfg_KeepOpen, SIGNAL(toggled(bool)), kcfg_KeepAbove, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_KeepOpen, SIGNAL(toggled(bool)), kcfg_ToggleToFocus, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(BehaviorSettings);
    } // setupUi

    void retranslateUi(QWidget *BehaviorSettings)
    {
        groupBox_1->setTitle(tr2i18n("General", "@title:group Group box label"));
        kcfg_FocusFollowsMouse->setText(tr2i18n("Focus terminals when the mouse pointer is moved over them", "@option:check"));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_ToggleToFocus->setWhatsThis(tr2i18n("If this option is enabled, the shortcut normally used to open and retract the window will give it focus, rather than close it, if it has previously lost focus. Unless the window is set to show on all virtual desktops, this may cause the window manager to switch to the virtual desktop it currently resides on.", "@info:whatsthis"));
#endif // QT_NO_WHATSTHIS
        kcfg_ToggleToFocus->setText(tr2i18n("Use Open/Retract action to focus window", "@option:check"));
        kcfg_KeepAbove->setText(tr2i18n("Keep window above other windows", "@option:check"));
        kcfg_OpenAfterStart->setText(tr2i18n("Open window after program start", "@option:check"));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_PollMouse->setWhatsThis(tr2i18n("If this option is enabled, the window will automatically open when the mouse pointer is moved to the same edge of the screen that it would open on when using the shortcut.", "@info:whatsthis"));
#endif // QT_NO_WHATSTHIS
        kcfg_PollMouse->setText(tr2i18n("Open window when the mouse pointer touches the screen edge", "@option:check"));
        kcfg_KeepOpen->setText(tr2i18n("Keep window open when it loses focus", "@option:check"));
        kcfg_KeepOpenAfterLastSessionCloses->setText(tr2i18n("Keep window open after the last session is closed", "@option:check"));
        groupBox_2->setTitle(tr2i18n("Dialogs", "@title:group"));
        kcfg_ConfirmQuit->setText(tr2i18n("Confirm quit when more than one session is open", "@option:check"));
        Q_UNUSED(BehaviorSettings);
    } // retranslateUi

};

namespace Ui {
    class BehaviorSettings: public Ui_BehaviorSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BEHAVIORSETTINGS_H

