/****************************************************************************
** Meta object code from reading C++ file 'appearancesettings.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/yakuake-3.0.2/app/config/appearancesettings.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appearancesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_AppearanceSettings_t {
    QByteArrayData data[18];
    char stringdata0[248];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AppearanceSettings_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AppearanceSettings_t qt_meta_stringdata_AppearanceSettings = {
    {
QT_MOC_LITERAL(0, 0, 18), // "AppearanceSettings"
QT_MOC_LITERAL(1, 19, 15), // "settingsChanged"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 14), // "resetSelection"
QT_MOC_LITERAL(4, 51, 16), // "populateSkinList"
QT_MOC_LITERAL(5, 68, 17), // "updateSkinSetting"
QT_MOC_LITERAL(6, 86, 11), // "installSkin"
QT_MOC_LITERAL(7, 98, 18), // "installSkinArchive"
QT_MOC_LITERAL(8, 117, 5), // "KJob*"
QT_MOC_LITERAL(9, 123, 9), // "deleteJob"
QT_MOC_LITERAL(10, 133, 12), // "validateSkin"
QT_MOC_LITERAL(11, 146, 6), // "skinId"
QT_MOC_LITERAL(12, 153, 8), // "fileList"
QT_MOC_LITERAL(13, 162, 17), // "extractKnsSkinIds"
QT_MOC_LITERAL(14, 180, 13), // "QSet<QString>"
QT_MOC_LITERAL(15, 194, 11), // "getNewSkins"
QT_MOC_LITERAL(16, 206, 22), // "updateRemoveSkinButton"
QT_MOC_LITERAL(17, 229, 18) // "removeSelectedSkin"

    },
    "AppearanceSettings\0settingsChanged\0\0"
    "resetSelection\0populateSkinList\0"
    "updateSkinSetting\0installSkin\0"
    "installSkinArchive\0KJob*\0deleteJob\0"
    "validateSkin\0skinId\0fileList\0"
    "extractKnsSkinIds\0QSet<QString>\0"
    "getNewSkins\0updateRemoveSkinButton\0"
    "removeSelectedSkin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AppearanceSettings[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   75,    2, 0x0a /* Public */,
       4,    0,   76,    2, 0x08 /* Private */,
       5,    0,   77,    2, 0x08 /* Private */,
       6,    0,   78,    2, 0x08 /* Private */,
       7,    1,   79,    2, 0x08 /* Private */,
       7,    0,   82,    2, 0x28 /* Private | MethodCloned */,
      10,    2,   83,    2, 0x08 /* Private */,
      13,    1,   88,    2, 0x08 /* Private */,
      15,    0,   91,    2, 0x08 /* Private */,
      16,    0,   92,    2, 0x08 /* Private */,
      17,    0,   93,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QString, QMetaType::QStringList,   11,   12,
    0x80000000 | 14, QMetaType::QStringList,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void AppearanceSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AppearanceSettings *_t = static_cast<AppearanceSettings *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->resetSelection(); break;
        case 2: _t->populateSkinList(); break;
        case 3: _t->updateSkinSetting(); break;
        case 4: _t->installSkin(); break;
        case 5: _t->installSkinArchive((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 6: _t->installSkinArchive(); break;
        case 7: { bool _r = _t->validateSkin((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = _r; }  break;
        case 8: { QSet<QString> _r = _t->extractKnsSkinIds((*reinterpret_cast< const QStringList(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QSet<QString>*>(_a[0]) = _r; }  break;
        case 9: _t->getNewSkins(); break;
        case 10: _t->updateRemoveSkinButton(); break;
        case 11: _t->removeSelectedSkin(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (AppearanceSettings::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AppearanceSettings::settingsChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject AppearanceSettings::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_AppearanceSettings.data,
      qt_meta_data_AppearanceSettings,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *AppearanceSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AppearanceSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_AppearanceSettings.stringdata0))
        return static_cast<void*>(const_cast< AppearanceSettings*>(this));
    return QWidget::qt_metacast(_clname);
}

int AppearanceSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void AppearanceSettings::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
