/****************************************************************************
** Meta object code from reading C++ file 'session.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/yakuake-3.0.2/app/session.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'session.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Session_t {
    QByteArrayData data[31];
    char stringdata0[420];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Session_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Session_t qt_meta_stringdata_Session = {
    {
QT_MOC_LITERAL(0, 0, 7), // "Session"
QT_MOC_LITERAL(1, 8, 12), // "titleChanged"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 5), // "title"
QT_MOC_LITERAL(4, 28, 9), // "sessionId"
QT_MOC_LITERAL(5, 38, 25), // "terminalManuallyActivated"
QT_MOC_LITERAL(6, 64, 9), // "Terminal*"
QT_MOC_LITERAL(7, 74, 8), // "terminal"
QT_MOC_LITERAL(8, 83, 20), // "keyboardInputBlocked"
QT_MOC_LITERAL(9, 104, 16), // "activityDetected"
QT_MOC_LITERAL(10, 121, 15), // "silenceDetected"
QT_MOC_LITERAL(11, 137, 9), // "destroyed"
QT_MOC_LITERAL(12, 147, 13), // "closeTerminal"
QT_MOC_LITERAL(13, 161, 10), // "terminalId"
QT_MOC_LITERAL(14, 172, 17), // "focusNextTerminal"
QT_MOC_LITERAL(15, 190, 21), // "focusPreviousTerminal"
QT_MOC_LITERAL(16, 212, 14), // "splitLeftRight"
QT_MOC_LITERAL(17, 227, 14), // "splitTopBottom"
QT_MOC_LITERAL(18, 242, 15), // "tryGrowTerminal"
QT_MOC_LITERAL(19, 258, 15), // "GrowthDirection"
QT_MOC_LITERAL(20, 274, 9), // "direction"
QT_MOC_LITERAL(21, 284, 6), // "pixels"
QT_MOC_LITERAL(22, 291, 10), // "runCommand"
QT_MOC_LITERAL(23, 302, 7), // "command"
QT_MOC_LITERAL(24, 310, 14), // "manageProfiles"
QT_MOC_LITERAL(25, 325, 11), // "editProfile"
QT_MOC_LITERAL(26, 337, 31), // "reconnectMonitorActivitySignals"
QT_MOC_LITERAL(27, 369, 17), // "setActiveTerminal"
QT_MOC_LITERAL(28, 387, 8), // "setTitle"
QT_MOC_LITERAL(29, 396, 7), // "cleanup"
QT_MOC_LITERAL(30, 404, 15) // "prepareShutdown"

    },
    "Session\0titleChanged\0\0title\0sessionId\0"
    "terminalManuallyActivated\0Terminal*\0"
    "terminal\0keyboardInputBlocked\0"
    "activityDetected\0silenceDetected\0"
    "destroyed\0closeTerminal\0terminalId\0"
    "focusNextTerminal\0focusPreviousTerminal\0"
    "splitLeftRight\0splitTopBottom\0"
    "tryGrowTerminal\0GrowthDirection\0"
    "direction\0pixels\0runCommand\0command\0"
    "manageProfiles\0editProfile\0"
    "reconnectMonitorActivitySignals\0"
    "setActiveTerminal\0setTitle\0cleanup\0"
    "prepareShutdown"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Session[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      26,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  144,    2, 0x06 /* Public */,
       1,    2,  147,    2, 0x06 /* Public */,
       5,    1,  152,    2, 0x06 /* Public */,
       8,    1,  155,    2, 0x06 /* Public */,
       9,    1,  158,    2, 0x06 /* Public */,
      10,    1,  161,    2, 0x06 /* Public */,
      11,    1,  164,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    1,  167,    2, 0x0a /* Public */,
      12,    0,  170,    2, 0x2a /* Public | MethodCloned */,
      14,    0,  171,    2, 0x0a /* Public */,
      15,    0,  172,    2, 0x0a /* Public */,
      16,    1,  173,    2, 0x0a /* Public */,
      16,    0,  176,    2, 0x2a /* Public | MethodCloned */,
      17,    1,  177,    2, 0x0a /* Public */,
      17,    0,  180,    2, 0x2a /* Public | MethodCloned */,
      18,    3,  181,    2, 0x0a /* Public */,
      22,    2,  188,    2, 0x0a /* Public */,
      22,    1,  193,    2, 0x2a /* Public | MethodCloned */,
      24,    0,  196,    2, 0x0a /* Public */,
      25,    0,  197,    2, 0x0a /* Public */,
      26,    0,  198,    2, 0x0a /* Public */,
      27,    1,  199,    2, 0x08 /* Private */,
      28,    2,  202,    2, 0x08 /* Private */,
      29,    1,  207,    2, 0x08 /* Private */,
      29,    0,  210,    2, 0x08 /* Private */,
      30,    0,  211,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,    3,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void, QMetaType::Int,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Int, QMetaType::Int,   13,
    QMetaType::Int,
    QMetaType::Int, QMetaType::Int,   13,
    QMetaType::Int,
    QMetaType::Int, QMetaType::Int, 0x80000000 | 19, QMetaType::UInt,   13,   20,   21,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   23,   13,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   13,    3,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Session::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Session *_t = static_cast<Session *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->titleChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->titleChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->terminalManuallyActivated((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 3: _t->keyboardInputBlocked((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 4: _t->activityDetected((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 5: _t->silenceDetected((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 6: _t->destroyed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->closeTerminal((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->closeTerminal(); break;
        case 9: _t->focusNextTerminal(); break;
        case 10: _t->focusPreviousTerminal(); break;
        case 11: { int _r = _t->splitLeftRight((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 12: { int _r = _t->splitLeftRight();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 13: { int _r = _t->splitTopBottom((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 14: { int _r = _t->splitTopBottom();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 15: { int _r = _t->tryGrowTerminal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< GrowthDirection(*)>(_a[2])),(*reinterpret_cast< uint(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 16: _t->runCommand((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 17: _t->runCommand((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->manageProfiles(); break;
        case 19: _t->editProfile(); break;
        case 20: _t->reconnectMonitorActivitySignals(); break;
        case 21: _t->setActiveTerminal((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->setTitle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 23: _t->cleanup((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->cleanup(); break;
        case 25: _t->prepareShutdown(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Session::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Session::titleChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Session::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Session::titleChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Session::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Session::terminalManuallyActivated)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Session::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Session::keyboardInputBlocked)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Session::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Session::activityDetected)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Session::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Session::silenceDetected)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Session::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Session::destroyed)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject Session::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Session.data,
      qt_meta_data_Session,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Session::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Session::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Session.stringdata0))
        return static_cast<void*>(const_cast< Session*>(this));
    return QObject::qt_metacast(_clname);
}

int Session::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void Session::titleChanged(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Session::titleChanged(int _t1, const QString & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Session::terminalManuallyActivated(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Session::keyboardInputBlocked(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Session::activityDetected(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Session::silenceDetected(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Session::destroyed(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_END_MOC_NAMESPACE
