#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'firstrundialog.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FIRSTRUNDIALOG_H
#define UI_FIRSTRUNDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "kkeysequencewidget.h"
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_FirstRunDialog
{
public:
    QGridLayout *gridLayout;
    KTitleWidget *titleWidget;
    QLabel *introLabel;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    KKeySequenceWidget *keyButton;
    QSpacerItem *spacerItem2;
    QSpacerItem *spacerItem3;
    QLabel *outroLabel;

    void setupUi(QWidget *FirstRunDialog)
    {
        if (FirstRunDialog->objectName().isEmpty())
            FirstRunDialog->setObjectName(QStringLiteral("FirstRunDialog"));
        FirstRunDialog->resize(400, 223);
        gridLayout = new QGridLayout(FirstRunDialog);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setHorizontalSpacing(0);
        gridLayout->setVerticalSpacing(0);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        titleWidget = new KTitleWidget(FirstRunDialog);
        titleWidget->setObjectName(QStringLiteral("titleWidget"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(titleWidget->sizePolicy().hasHeightForWidth());
        titleWidget->setSizePolicy(sizePolicy);
        titleWidget->setMinimumSize(QSize(0, 42));

        gridLayout->addWidget(titleWidget, 0, 0, 1, 3);

        introLabel = new QLabel(FirstRunDialog);
        introLabel->setObjectName(QStringLiteral("introLabel"));
        introLabel->setWordWrap(true);

        gridLayout->addWidget(introLabel, 1, 0, 1, 3);

        spacerItem = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(spacerItem, 2, 1, 1, 1);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem1, 3, 0, 1, 1);

        keyButton = new KKeySequenceWidget(FirstRunDialog);
        keyButton->setObjectName(QStringLiteral("keyButton"));

        gridLayout->addWidget(keyButton, 3, 1, 1, 1);

        spacerItem2 = new QSpacerItem(50, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem2, 3, 2, 1, 1);

        spacerItem3 = new QSpacerItem(20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(spacerItem3, 4, 1, 1, 1);

        outroLabel = new QLabel(FirstRunDialog);
        outroLabel->setObjectName(QStringLiteral("outroLabel"));
        outroLabel->setWordWrap(true);

        gridLayout->addWidget(outroLabel, 5, 0, 1, 3);


        retranslateUi(FirstRunDialog);

        QMetaObject::connectSlotsByName(FirstRunDialog);
    } // setupUi

    void retranslateUi(QWidget *FirstRunDialog)
    {
        titleWidget->setText(tr2i18n("Welcome to Yakuake", "@title"));
        introLabel->setText(tr2i18n("Before starting to use the application, you might want to change the keyboard shortcut used to open and retract the Yakuake window:", "@info"));
        outroLabel->setText(tr2i18n("You can change the shortcut later at any time via the menu.", "@info"));
        Q_UNUSED(FirstRunDialog);
    } // retranslateUi

};

namespace Ui {
    class FirstRunDialog: public Ui_FirstRunDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FIRSTRUNDIALOG_H

