#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'windowsettings.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WINDOWSETTINGS_H
#define UI_WINDOWSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_WindowSettings
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_1;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_ShowTabBar;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_DynamicTabTitles;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_1;
    QLabel *widthLabel;
    QSlider *widthSlider;
    QSpinBox *kcfg_Width;
    QLabel *heightLabel;
    QSlider *heightSlider;
    QSpinBox *kcfg_Height;
    QLabel *durationLabel;
    QSlider *kcfg_Frames;
    QSpinBox *framesSpinBox;
    QCheckBox *kcfg_UseWMAssist;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *hboxLayout;
    QLabel *leftLabel;
    QSlider *kcfg_Position;
    QLabel *rightLabel;
    QHBoxLayout *hboxLayout1;
    QLabel *screenLabel;
    QComboBox *kcfg_Screen;
    QSpacerItem *spacerItem1;
    QCheckBox *kcfg_ShowOnAllDesktops;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *WindowSettings)
    {
        if (WindowSettings->objectName().isEmpty())
            WindowSettings->setObjectName(QStringLiteral("WindowSettings"));
        WindowSettings->resize(289, 441);
        verticalLayout = new QVBoxLayout(WindowSettings);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        groupBox_1 = new QGroupBox(WindowSettings);
        groupBox_1->setObjectName(QStringLiteral("groupBox_1"));
        gridLayout = new QGridLayout(groupBox_1);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        kcfg_ShowTabBar = new QCheckBox(groupBox_1);
        kcfg_ShowTabBar->setObjectName(QStringLiteral("kcfg_ShowTabBar"));

        gridLayout->addWidget(kcfg_ShowTabBar, 0, 0, 1, 2);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        gridLayout->addItem(spacerItem, 1, 0, 1, 1);

        kcfg_DynamicTabTitles = new QCheckBox(groupBox_1);
        kcfg_DynamicTabTitles->setObjectName(QStringLiteral("kcfg_DynamicTabTitles"));
        kcfg_DynamicTabTitles->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_DynamicTabTitles->sizePolicy().hasHeightForWidth());
        kcfg_DynamicTabTitles->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_DynamicTabTitles, 1, 1, 1, 1);


        verticalLayout->addWidget(groupBox_1);

        groupBox_2 = new QGroupBox(WindowSettings);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        gridLayout_1 = new QGridLayout(groupBox_2);
        gridLayout_1->setObjectName(QStringLiteral("gridLayout_1"));
        widthLabel = new QLabel(groupBox_2);
        widthLabel->setObjectName(QStringLiteral("widthLabel"));

        gridLayout_1->addWidget(widthLabel, 0, 0, 1, 1);

        widthSlider = new QSlider(groupBox_2);
        widthSlider->setObjectName(QStringLiteral("widthSlider"));
        widthSlider->setMinimum(1);
        widthSlider->setMaximum(10);
        widthSlider->setPageStep(1);
        widthSlider->setValue(9);
        widthSlider->setOrientation(Qt::Horizontal);
        widthSlider->setTickPosition(QSlider::TicksBelow);
        widthSlider->setTickInterval(1);

        gridLayout_1->addWidget(widthSlider, 0, 1, 1, 1);

        kcfg_Width = new QSpinBox(groupBox_2);
        kcfg_Width->setObjectName(QStringLiteral("kcfg_Width"));
        kcfg_Width->setCorrectionMode(QAbstractSpinBox::CorrectToNearestValue);
        kcfg_Width->setMinimum(10);
        kcfg_Width->setMaximum(100);
        kcfg_Width->setSingleStep(10);
        kcfg_Width->setValue(90);

        gridLayout_1->addWidget(kcfg_Width, 0, 2, 1, 1);

        heightLabel = new QLabel(groupBox_2);
        heightLabel->setObjectName(QStringLiteral("heightLabel"));

        gridLayout_1->addWidget(heightLabel, 1, 0, 1, 1);

        heightSlider = new QSlider(groupBox_2);
        heightSlider->setObjectName(QStringLiteral("heightSlider"));
        heightSlider->setMinimum(1);
        heightSlider->setMaximum(10);
        heightSlider->setPageStep(1);
        heightSlider->setValue(5);
        heightSlider->setOrientation(Qt::Horizontal);
        heightSlider->setTickPosition(QSlider::TicksBelow);
        heightSlider->setTickInterval(1);

        gridLayout_1->addWidget(heightSlider, 1, 1, 1, 1);

        kcfg_Height = new QSpinBox(groupBox_2);
        kcfg_Height->setObjectName(QStringLiteral("kcfg_Height"));
        kcfg_Height->setCorrectionMode(QAbstractSpinBox::CorrectToNearestValue);
        kcfg_Height->setMinimum(10);
        kcfg_Height->setMaximum(100);
        kcfg_Height->setSingleStep(10);
        kcfg_Height->setValue(50);

        gridLayout_1->addWidget(kcfg_Height, 1, 2, 1, 1);

        durationLabel = new QLabel(groupBox_2);
        durationLabel->setObjectName(QStringLiteral("durationLabel"));

        gridLayout_1->addWidget(durationLabel, 2, 0, 1, 1);

        kcfg_Frames = new QSlider(groupBox_2);
        kcfg_Frames->setObjectName(QStringLiteral("kcfg_Frames"));
        kcfg_Frames->setMaximum(50);
        kcfg_Frames->setPageStep(1);
        kcfg_Frames->setValue(25);
        kcfg_Frames->setOrientation(Qt::Horizontal);
        kcfg_Frames->setTickPosition(QSlider::TicksBelow);
        kcfg_Frames->setTickInterval(5);

        gridLayout_1->addWidget(kcfg_Frames, 2, 1, 1, 1);

        framesSpinBox = new QSpinBox(groupBox_2);
        framesSpinBox->setObjectName(QStringLiteral("framesSpinBox"));
        framesSpinBox->setCorrectionMode(QAbstractSpinBox::CorrectToNearestValue);
        framesSpinBox->setMaximum(500);
        framesSpinBox->setSingleStep(10);
        framesSpinBox->setValue(200);

        gridLayout_1->addWidget(framesSpinBox, 2, 2, 1, 1);

        kcfg_UseWMAssist = new QCheckBox(groupBox_2);
        kcfg_UseWMAssist->setObjectName(QStringLiteral("kcfg_UseWMAssist"));

        gridLayout_1->addWidget(kcfg_UseWMAssist, 3, 0, 1, 3);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(WindowSettings);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        leftLabel = new QLabel(groupBox_3);
        leftLabel->setObjectName(QStringLiteral("leftLabel"));

        hboxLayout->addWidget(leftLabel);

        kcfg_Position = new QSlider(groupBox_3);
        kcfg_Position->setObjectName(QStringLiteral("kcfg_Position"));
        kcfg_Position->setMaximum(100);
        kcfg_Position->setSingleStep(10);
        kcfg_Position->setValue(50);
        kcfg_Position->setTracking(true);
        kcfg_Position->setOrientation(Qt::Horizontal);
        kcfg_Position->setTickPosition(QSlider::TicksBelow);
        kcfg_Position->setTickInterval(10);

        hboxLayout->addWidget(kcfg_Position);

        rightLabel = new QLabel(groupBox_3);
        rightLabel->setObjectName(QStringLiteral("rightLabel"));

        hboxLayout->addWidget(rightLabel);


        verticalLayout_2->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        screenLabel = new QLabel(groupBox_3);
        screenLabel->setObjectName(QStringLiteral("screenLabel"));
        screenLabel->setEnabled(false);

        hboxLayout1->addWidget(screenLabel);

        kcfg_Screen = new QComboBox(groupBox_3);
        kcfg_Screen->setObjectName(QStringLiteral("kcfg_Screen"));
        kcfg_Screen->setEnabled(false);

        hboxLayout1->addWidget(kcfg_Screen);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem1);


        verticalLayout_2->addLayout(hboxLayout1);

        kcfg_ShowOnAllDesktops = new QCheckBox(groupBox_3);
        kcfg_ShowOnAllDesktops->setObjectName(QStringLiteral("kcfg_ShowOnAllDesktops"));

        verticalLayout_2->addWidget(kcfg_ShowOnAllDesktops);


        verticalLayout->addWidget(groupBox_3);

        spacerItem2 = new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(spacerItem2);

        QWidget::setTabOrder(kcfg_ShowTabBar, kcfg_DynamicTabTitles);
        QWidget::setTabOrder(kcfg_DynamicTabTitles, widthSlider);
        QWidget::setTabOrder(widthSlider, kcfg_Width);
        QWidget::setTabOrder(kcfg_Width, heightSlider);
        QWidget::setTabOrder(heightSlider, kcfg_Height);
        QWidget::setTabOrder(kcfg_Height, kcfg_Frames);
        QWidget::setTabOrder(kcfg_Frames, framesSpinBox);
        QWidget::setTabOrder(framesSpinBox, kcfg_UseWMAssist);
        QWidget::setTabOrder(kcfg_UseWMAssist, kcfg_Position);
        QWidget::setTabOrder(kcfg_Position, kcfg_Screen);
        QWidget::setTabOrder(kcfg_Screen, kcfg_ShowOnAllDesktops);

        retranslateUi(WindowSettings);
        QObject::connect(kcfg_ShowTabBar, SIGNAL(toggled(bool)), kcfg_DynamicTabTitles, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(WindowSettings);
    } // setupUi

    void retranslateUi(QWidget *WindowSettings)
    {
        groupBox_1->setTitle(tr2i18n("Tab Bar", "@title:group"));
        kcfg_ShowTabBar->setText(tr2i18n("Show the tab bar", "@option:check"));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_DynamicTabTitles->setWhatsThis(tr2i18n("If this option is enabled, the information about the active terminal's contents that is normally shown in the title bar will also be shown on the tab bar. You can modify the format of the information in the terminal profile.", "@info:whatsthis"));
#endif // QT_NO_WHATSTHIS
        kcfg_DynamicTabTitles->setText(tr2i18n("Show title bar contents in tab labels", "@option:check"));
        groupBox_2->setTitle(tr2i18n("Size and Animation", "@title:group"));
        widthLabel->setText(tr2i18n("Width:", "@label:slider"));
        kcfg_Width->setSuffix(tr2i18n("%", "@label Spinbox unit suffix"));
        heightLabel->setText(tr2i18n("Height:", "@label:slider"));
        kcfg_Height->setSuffix(tr2i18n("%", "@label Spinbox unit suffix"));
        durationLabel->setText(tr2i18n("Duration:", "@label:slider"));
        framesSpinBox->setSuffix(tr2i18n("ms", "@label Spinbox unit suffix"));
        framesSpinBox->setPrefix(tr2i18n("~", "@label Spinbox unit prefix"));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_UseWMAssist->setWhatsThis(tr2i18n("If this option is enabled, Yakuake will ask the window manager to perform the window open/retract animation. If the window manager is unable to provide the requested service, Yakuake will fall back to an animation strategy of progressively adjusting the window mask.", "@info:whatsthis"));
#endif // QT_NO_WHATSTHIS
        kcfg_UseWMAssist->setText(tr2i18n("Ask the window manager to perform the animation", "@option:check"));
        groupBox_3->setTitle(tr2i18n("Position", "@title:group"));
        leftLabel->setText(tr2i18n("Left", "@item:inrange Direction to move the window in"));
        rightLabel->setText(tr2i18n("Right", "@item:inrange Direction to move the window in"));
        screenLabel->setText(tr2i18n("Open on screen:", "@label:listbox"));
        kcfg_Screen->clear();
        kcfg_Screen->insertItems(0, QStringList()
         << tr2i18n("At mouse location", "@item:inlistbox")
         << tr2i18n("Screen 1", "@item:inlistbox")
        );
        kcfg_ShowOnAllDesktops->setText(tr2i18n("Show on all desktops", "@option:check"));
        Q_UNUSED(WindowSettings);
    } // retranslateUi

};

namespace Ui {
    class WindowSettings: public Ui_WindowSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WINDOWSETTINGS_H

