/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/yakuake-3.0.2/app/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[56];
    char stringdata0[901];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 27, 15), // "org.kde.yakuake"
QT_MOC_LITERAL(3, 43, 12), // "windowOpened"
QT_MOC_LITERAL(4, 56, 0), // ""
QT_MOC_LITERAL(5, 57, 12), // "windowClosed"
QT_MOC_LITERAL(6, 70, 17), // "toggleWindowState"
QT_MOC_LITERAL(7, 88, 28), // "handleContextDependentAction"
QT_MOC_LITERAL(8, 117, 8), // "QAction*"
QT_MOC_LITERAL(9, 126, 6), // "action"
QT_MOC_LITERAL(10, 133, 9), // "sessionId"
QT_MOC_LITERAL(11, 143, 34), // "handleContextDependentToggleA..."
QT_MOC_LITERAL(12, 178, 7), // "checked"
QT_MOC_LITERAL(13, 186, 33), // "handleToggleTerminalKeyboardI..."
QT_MOC_LITERAL(14, 220, 35), // "handleToggleTerminalMonitorAc..."
QT_MOC_LITERAL(15, 256, 34), // "handleToggleTerminalMonitorSi..."
QT_MOC_LITERAL(16, 291, 22), // "handleTerminalActivity"
QT_MOC_LITERAL(17, 314, 9), // "Terminal*"
QT_MOC_LITERAL(18, 324, 8), // "terminal"
QT_MOC_LITERAL(19, 333, 21), // "handleTerminalSilence"
QT_MOC_LITERAL(20, 355, 19), // "handleLastTabClosed"
QT_MOC_LITERAL(21, 375, 13), // "applySettings"
QT_MOC_LITERAL(22, 389, 9), // "applySkin"
QT_MOC_LITERAL(23, 399, 21), // "applyWindowProperties"
QT_MOC_LITERAL(24, 421, 19), // "applyWindowGeometry"
QT_MOC_LITERAL(25, 441, 17), // "setWindowGeometry"
QT_MOC_LITERAL(26, 459, 5), // "width"
QT_MOC_LITERAL(27, 465, 6), // "height"
QT_MOC_LITERAL(28, 472, 8), // "position"
QT_MOC_LITERAL(29, 481, 16), // "updateScreenMenu"
QT_MOC_LITERAL(30, 498, 9), // "setScreen"
QT_MOC_LITERAL(31, 508, 14), // "setWindowWidth"
QT_MOC_LITERAL(32, 523, 15), // "setWindowHeight"
QT_MOC_LITERAL(33, 539, 19), // "increaseWindowWidth"
QT_MOC_LITERAL(34, 559, 19), // "decreaseWindowWidth"
QT_MOC_LITERAL(35, 579, 20), // "increaseWindowHeight"
QT_MOC_LITERAL(36, 600, 20), // "decreaseWindowHeight"
QT_MOC_LITERAL(37, 621, 21), // "wmActiveWindowChanged"
QT_MOC_LITERAL(38, 643, 16), // "xshapeOpenWindow"
QT_MOC_LITERAL(39, 660, 19), // "xshapeRetractWindow"
QT_MOC_LITERAL(40, 680, 8), // "activate"
QT_MOC_LITERAL(41, 689, 15), // "toggleMousePoll"
QT_MOC_LITERAL(42, 705, 4), // "poll"
QT_MOC_LITERAL(43, 710, 9), // "pollMouse"
QT_MOC_LITERAL(44, 720, 11), // "setKeepOpen"
QT_MOC_LITERAL(45, 732, 8), // "keepOpen"
QT_MOC_LITERAL(46, 741, 13), // "setFullScreen"
QT_MOC_LITERAL(47, 755, 5), // "state"
QT_MOC_LITERAL(48, 761, 20), // "handleSwitchToAction"
QT_MOC_LITERAL(49, 782, 9), // "whatsThis"
QT_MOC_LITERAL(50, 792, 13), // "configureKeys"
QT_MOC_LITERAL(51, 806, 22), // "configureNotifications"
QT_MOC_LITERAL(52, 829, 12), // "configureApp"
QT_MOC_LITERAL(53, 842, 18), // "showFirstRunDialog"
QT_MOC_LITERAL(54, 861, 22), // "firstRunDialogFinished"
QT_MOC_LITERAL(55, 884, 16) // "firstRunDialogOk"

    },
    "MainWindow\0D-Bus Interface\0org.kde.yakuake\0"
    "windowOpened\0\0windowClosed\0toggleWindowState\0"
    "handleContextDependentAction\0QAction*\0"
    "action\0sessionId\0handleContextDependentToggleAction\0"
    "checked\0handleToggleTerminalKeyboardInput\0"
    "handleToggleTerminalMonitorActivity\0"
    "handleToggleTerminalMonitorSilence\0"
    "handleTerminalActivity\0Terminal*\0"
    "terminal\0handleTerminalSilence\0"
    "handleLastTabClosed\0applySettings\0"
    "applySkin\0applyWindowProperties\0"
    "applyWindowGeometry\0setWindowGeometry\0"
    "width\0height\0position\0updateScreenMenu\0"
    "setScreen\0setWindowWidth\0setWindowHeight\0"
    "increaseWindowWidth\0decreaseWindowWidth\0"
    "increaseWindowHeight\0decreaseWindowHeight\0"
    "wmActiveWindowChanged\0xshapeOpenWindow\0"
    "xshapeRetractWindow\0activate\0"
    "toggleMousePoll\0poll\0pollMouse\0"
    "setKeepOpen\0keepOpen\0setFullScreen\0"
    "state\0handleSwitchToAction\0whatsThis\0"
    "configureKeys\0configureNotifications\0"
    "configureApp\0showFirstRunDialog\0"
    "firstRunDialogFinished\0firstRunDialogOk"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      46,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,  246,    4, 0x06 /* Public */,
       5,    0,  247,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,  248,    4, 0x4a /* Public | isScriptable */,
       7,    2,  249,    4, 0x0a /* Public */,
       7,    1,  254,    4, 0x2a /* Public | MethodCloned */,
       7,    0,  257,    4, 0x2a /* Public | MethodCloned */,
      11,    3,  258,    4, 0x0a /* Public */,
      11,    2,  265,    4, 0x2a /* Public | MethodCloned */,
      11,    1,  270,    4, 0x2a /* Public | MethodCloned */,
      13,    1,  273,    4, 0x0a /* Public */,
      14,    1,  276,    4, 0x0a /* Public */,
      15,    1,  279,    4, 0x0a /* Public */,
      16,    1,  282,    4, 0x0a /* Public */,
      19,    1,  285,    4, 0x0a /* Public */,
      20,    0,  288,    4, 0x0a /* Public */,
      21,    0,  289,    4, 0x08 /* Private */,
      22,    0,  290,    4, 0x08 /* Private */,
      23,    0,  291,    4, 0x08 /* Private */,
      24,    0,  292,    4, 0x08 /* Private */,
      25,    3,  293,    4, 0x08 /* Private */,
      29,    0,  300,    4, 0x08 /* Private */,
      30,    1,  301,    4, 0x08 /* Private */,
      31,    1,  304,    4, 0x08 /* Private */,
      32,    1,  307,    4, 0x08 /* Private */,
      31,    1,  310,    4, 0x08 /* Private */,
      32,    1,  313,    4, 0x08 /* Private */,
      33,    0,  316,    4, 0x08 /* Private */,
      34,    0,  317,    4, 0x08 /* Private */,
      35,    0,  318,    4, 0x08 /* Private */,
      36,    0,  319,    4, 0x08 /* Private */,
      37,    0,  320,    4, 0x08 /* Private */,
      38,    0,  321,    4, 0x08 /* Private */,
      39,    0,  322,    4, 0x08 /* Private */,
      40,    0,  323,    4, 0x08 /* Private */,
      41,    1,  324,    4, 0x08 /* Private */,
      43,    0,  327,    4, 0x08 /* Private */,
      44,    1,  328,    4, 0x08 /* Private */,
      46,    1,  331,    4, 0x08 /* Private */,
      48,    0,  334,    4, 0x08 /* Private */,
      49,    0,  335,    4, 0x08 /* Private */,
      50,    0,  336,    4, 0x08 /* Private */,
      51,    0,  337,    4, 0x08 /* Private */,
      52,    0,  338,    4, 0x08 /* Private */,
      53,    0,  339,    4, 0x08 /* Private */,
      54,    0,  340,    4, 0x08 /* Private */,
      55,    0,  341,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8, QMetaType::Int,    9,   10,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 8, QMetaType::Int,   12,    9,   10,
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 8,   12,    9,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, QMetaType::Bool,   12,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,   26,   27,   28,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, QMetaType::Int,   26,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   42,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   45,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->windowOpened(); break;
        case 1: _t->windowClosed(); break;
        case 2: _t->toggleWindowState(); break;
        case 3: _t->handleContextDependentAction((*reinterpret_cast< QAction*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->handleContextDependentAction((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 5: _t->handleContextDependentAction(); break;
        case 6: _t->handleContextDependentToggleAction((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< QAction*(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 7: _t->handleContextDependentToggleAction((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< QAction*(*)>(_a[2]))); break;
        case 8: _t->handleContextDependentToggleAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->handleToggleTerminalKeyboardInput((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->handleToggleTerminalMonitorActivity((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->handleToggleTerminalMonitorSilence((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->handleTerminalActivity((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 13: _t->handleTerminalSilence((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 14: _t->handleLastTabClosed(); break;
        case 15: _t->applySettings(); break;
        case 16: _t->applySkin(); break;
        case 17: _t->applyWindowProperties(); break;
        case 18: _t->applyWindowGeometry(); break;
        case 19: _t->setWindowGeometry((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 20: _t->updateScreenMenu(); break;
        case 21: _t->setScreen((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 22: _t->setWindowWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->setWindowHeight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->setWindowWidth((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 25: _t->setWindowHeight((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 26: _t->increaseWindowWidth(); break;
        case 27: _t->decreaseWindowWidth(); break;
        case 28: _t->increaseWindowHeight(); break;
        case 29: _t->decreaseWindowHeight(); break;
        case 30: _t->wmActiveWindowChanged(); break;
        case 31: _t->xshapeOpenWindow(); break;
        case 32: _t->xshapeRetractWindow(); break;
        case 33: _t->activate(); break;
        case 34: _t->toggleMousePoll((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 35: _t->pollMouse(); break;
        case 36: _t->setKeepOpen((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 37: _t->setFullScreen((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 38: _t->handleSwitchToAction(); break;
        case 39: _t->whatsThis(); break;
        case 40: _t->configureKeys(); break;
        case 41: _t->configureNotifications(); break;
        case 42: _t->configureApp(); break;
        case 43: _t->showFirstRunDialog(); break;
        case 44: _t->firstRunDialogFinished(); break;
        case 45: _t->firstRunDialogOk(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (MainWindow::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MainWindow::windowOpened)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (MainWindow::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&MainWindow::windowClosed)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject MainWindow::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_MainWindow.data,
      qt_meta_data_MainWindow,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(const_cast< MainWindow*>(this));
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 46)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 46;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 46)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 46;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::windowOpened()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void MainWindow::windowClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
