/****************************************************************************
** Meta object code from reading C++ file 'terminal.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/yakuake-3.0.2/app/terminal.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'terminal.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_Terminal_t {
    QByteArrayData data[19];
    char stringdata0[209];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Terminal_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Terminal_t qt_meta_stringdata_Terminal = {
    {
QT_MOC_LITERAL(0, 0, 8), // "Terminal"
QT_MOC_LITERAL(1, 9, 12), // "titleChanged"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 10), // "terminalId"
QT_MOC_LITERAL(4, 34, 5), // "title"
QT_MOC_LITERAL(5, 40, 9), // "activated"
QT_MOC_LITERAL(6, 50, 17), // "manuallyActivated"
QT_MOC_LITERAL(7, 68, 9), // "Terminal*"
QT_MOC_LITERAL(8, 78, 8), // "terminal"
QT_MOC_LITERAL(9, 87, 20), // "keyboardInputBlocked"
QT_MOC_LITERAL(10, 108, 16), // "activityDetected"
QT_MOC_LITERAL(11, 125, 15), // "silenceDetected"
QT_MOC_LITERAL(12, 141, 9), // "destroyed"
QT_MOC_LITERAL(13, 151, 8), // "setTitle"
QT_MOC_LITERAL(14, 160, 16), // "overrideShortcut"
QT_MOC_LITERAL(15, 177, 10), // "QKeyEvent*"
QT_MOC_LITERAL(16, 188, 5), // "event"
QT_MOC_LITERAL(17, 194, 5), // "bool&"
QT_MOC_LITERAL(18, 200, 8) // "override"

    },
    "Terminal\0titleChanged\0\0terminalId\0"
    "title\0activated\0manuallyActivated\0"
    "Terminal*\0terminal\0keyboardInputBlocked\0"
    "activityDetected\0silenceDetected\0"
    "destroyed\0setTitle\0overrideShortcut\0"
    "QKeyEvent*\0event\0bool&\0override"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Terminal[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   69,    2, 0x06 /* Public */,
       5,    1,   74,    2, 0x06 /* Public */,
       6,    1,   77,    2, 0x06 /* Public */,
       9,    1,   80,    2, 0x06 /* Public */,
      10,    1,   83,    2, 0x06 /* Public */,
      11,    1,   86,    2, 0x06 /* Public */,
      12,    1,   89,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    1,   92,    2, 0x08 /* Private */,
      14,    2,   95,    2, 0x08 /* Private */,
      11,    0,  100,    2, 0x08 /* Private */,
      10,    0,  101,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, QMetaType::Int,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, 0x80000000 | 15, 0x80000000 | 17,   16,   18,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Terminal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Terminal *_t = static_cast<Terminal *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->titleChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->manuallyActivated((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 3: _t->keyboardInputBlocked((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 4: _t->activityDetected((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 5: _t->silenceDetected((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 6: _t->destroyed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->setTitle((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->overrideShortcut((*reinterpret_cast< QKeyEvent*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 9: _t->silenceDetected(); break;
        case 10: _t->activityDetected(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Terminal* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Terminal* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Terminal* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Terminal* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Terminal::*_t)(int , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Terminal::titleChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Terminal::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Terminal::activated)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Terminal::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Terminal::manuallyActivated)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Terminal::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Terminal::keyboardInputBlocked)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Terminal::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Terminal::activityDetected)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Terminal::*_t)(Terminal * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Terminal::silenceDetected)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Terminal::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Terminal::destroyed)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject Terminal::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Terminal.data,
      qt_meta_data_Terminal,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *Terminal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Terminal::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_Terminal.stringdata0))
        return static_cast<void*>(const_cast< Terminal*>(this));
    return QObject::qt_metacast(_clname);
}

int Terminal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Terminal::titleChanged(int _t1, const QString & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Terminal::activated(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Terminal::manuallyActivated(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Terminal::keyboardInputBlocked(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void Terminal::activityDetected(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Terminal::silenceDetected(Terminal * _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Terminal::destroyed(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}
QT_END_MOC_NAMESPACE
