/****************************************************************************
** Meta object code from reading C++ file 'tabbar.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/yakuake-3.0.2/app/tabbar.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_TabBar_t {
    QByteArrayData data[33];
    char stringdata0[449];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TabBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TabBar_t qt_meta_stringdata_TabBar = {
    {
QT_MOC_LITERAL(0, 0, 6), // "TabBar"
QT_MOC_LITERAL(1, 7, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 23, 15), // "org.kde.yakuake"
QT_MOC_LITERAL(3, 39, 15), // "newTabRequested"
QT_MOC_LITERAL(4, 55, 0), // ""
QT_MOC_LITERAL(5, 56, 11), // "tabSelected"
QT_MOC_LITERAL(6, 68, 9), // "sessionId"
QT_MOC_LITERAL(7, 78, 9), // "tabClosed"
QT_MOC_LITERAL(8, 88, 24), // "requestTerminalHighlight"
QT_MOC_LITERAL(9, 113, 10), // "terminalId"
QT_MOC_LITERAL(10, 124, 30), // "requestRemoveTerminalHighlight"
QT_MOC_LITERAL(11, 155, 20), // "tabContextMenuClosed"
QT_MOC_LITERAL(12, 176, 13), // "lastTabClosed"
QT_MOC_LITERAL(13, 190, 6), // "addTab"
QT_MOC_LITERAL(14, 197, 5), // "title"
QT_MOC_LITERAL(15, 203, 9), // "removeTab"
QT_MOC_LITERAL(16, 213, 17), // "interactiveRename"
QT_MOC_LITERAL(17, 231, 9), // "selectTab"
QT_MOC_LITERAL(18, 241, 13), // "selectNextTab"
QT_MOC_LITERAL(19, 255, 17), // "selectPreviousTab"
QT_MOC_LITERAL(20, 273, 11), // "moveTabLeft"
QT_MOC_LITERAL(21, 285, 12), // "moveTabRight"
QT_MOC_LITERAL(22, 298, 8), // "tabTitle"
QT_MOC_LITERAL(23, 307, 11), // "setTabTitle"
QT_MOC_LITERAL(24, 319, 8), // "newTitle"
QT_MOC_LITERAL(25, 328, 12), // "sessionAtTab"
QT_MOC_LITERAL(26, 341, 5), // "index"
QT_MOC_LITERAL(27, 347, 16), // "readySessionMenu"
QT_MOC_LITERAL(28, 364, 24), // "contextMenuActionHovered"
QT_MOC_LITERAL(29, 389, 8), // "QAction*"
QT_MOC_LITERAL(30, 398, 6), // "action"
QT_MOC_LITERAL(31, 405, 21), // "closeTabButtonClicked"
QT_MOC_LITERAL(32, 427, 21) // "interactiveRenameDone"

    },
    "TabBar\0D-Bus Interface\0org.kde.yakuake\0"
    "newTabRequested\0\0tabSelected\0sessionId\0"
    "tabClosed\0requestTerminalHighlight\0"
    "terminalId\0requestRemoveTerminalHighlight\0"
    "tabContextMenuClosed\0lastTabClosed\0"
    "addTab\0title\0removeTab\0interactiveRename\0"
    "selectTab\0selectNextTab\0selectPreviousTab\0"
    "moveTabLeft\0moveTabRight\0tabTitle\0"
    "setTabTitle\0newTitle\0sessionAtTab\0"
    "index\0readySessionMenu\0contextMenuActionHovered\0"
    "QAction*\0action\0closeTabButtonClicked\0"
    "interactiveRenameDone"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TabBar[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      25,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,  141,    4, 0x06 /* Public */,
       5,    1,  142,    4, 0x06 /* Public */,
       7,    1,  145,    4, 0x06 /* Public */,
       8,    1,  148,    4, 0x06 /* Public */,
      10,    0,  151,    4, 0x06 /* Public */,
      11,    0,  152,    4, 0x06 /* Public */,
      12,    0,  153,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    2,  154,    4, 0x0a /* Public */,
      15,    1,  159,    4, 0x0a /* Public */,
      15,    0,  162,    4, 0x2a /* Public | MethodCloned */,
      16,    1,  163,    4, 0x0a /* Public */,
      17,    1,  166,    4, 0x0a /* Public */,
      18,    0,  169,    4, 0x0a /* Public */,
      19,    0,  170,    4, 0x0a /* Public */,
      20,    1,  171,    4, 0x0a /* Public */,
      20,    0,  174,    4, 0x2a /* Public | MethodCloned */,
      21,    1,  175,    4, 0x0a /* Public */,
      21,    0,  178,    4, 0x2a /* Public | MethodCloned */,
      22,    1,  179,    4, 0x4a /* Public | isScriptable */,
      23,    2,  182,    4, 0x4a /* Public | isScriptable */,
      25,    1,  187,    4, 0x4a /* Public | isScriptable */,
      27,    0,  190,    4, 0x08 /* Private */,
      28,    1,  191,    4, 0x08 /* Private */,
      31,    0,  194,    4, 0x08 /* Private */,
      32,    0,  195,    4, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    6,   14,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::QString, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    6,   24,
    QMetaType::Int, QMetaType::Int,   26,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void TabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TabBar *_t = static_cast<TabBar *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newTabRequested(); break;
        case 1: _t->tabSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->tabClosed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->requestTerminalHighlight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->requestRemoveTerminalHighlight(); break;
        case 5: _t->tabContextMenuClosed(); break;
        case 6: _t->lastTabClosed(); break;
        case 7: _t->addTab((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 8: _t->removeTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->removeTab(); break;
        case 10: _t->interactiveRename((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->selectTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->selectNextTab(); break;
        case 13: _t->selectPreviousTab(); break;
        case 14: _t->moveTabLeft((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->moveTabLeft(); break;
        case 16: _t->moveTabRight((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->moveTabRight(); break;
        case 18: { QString _r = _t->tabTitle((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = _r; }  break;
        case 19: _t->setTabTitle((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 20: { int _r = _t->sessionAtTab((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = _r; }  break;
        case 21: _t->readySessionMenu(); break;
        case 22: _t->contextMenuActionHovered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 23: _t->closeTabButtonClicked(); break;
        case 24: _t->interactiveRenameDone(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (TabBar::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabBar::newTabRequested)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabBar::tabSelected)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabBar::tabClosed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (TabBar::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabBar::requestTerminalHighlight)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (TabBar::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabBar::requestRemoveTerminalHighlight)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (TabBar::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabBar::tabContextMenuClosed)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (TabBar::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TabBar::lastTabClosed)) {
                *result = 6;
                return;
            }
        }
    }
}

const QMetaObject TabBar::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_TabBar.data,
      qt_meta_data_TabBar,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *TabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_TabBar.stringdata0))
        return static_cast<void*>(const_cast< TabBar*>(this));
    return QWidget::qt_metacast(_clname);
}

int TabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void TabBar::newTabRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void TabBar::tabSelected(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void TabBar::tabClosed(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void TabBar::requestTerminalHighlight(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void TabBar::requestRemoveTerminalHighlight()
{
    QMetaObject::activate(this, &staticMetaObject, 4, Q_NULLPTR);
}

// SIGNAL 5
void TabBar::tabContextMenuClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, Q_NULLPTR);
}

// SIGNAL 6
void TabBar::lastTabClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, Q_NULLPTR);
}
QT_END_MOC_NAMESPACE
