/****************************************************************************
** Meta object code from reading C++ file 'visualeventoverlay.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/yakuake-3.0.2/app/visualeventoverlay.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'visualeventoverlay.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_VisualEventOverlay_t {
    QByteArrayData data[14];
    char stringdata0[204];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_VisualEventOverlay_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_VisualEventOverlay_t qt_meta_stringdata_VisualEventOverlay = {
    {
QT_MOC_LITERAL(0, 0, 18), // "VisualEventOverlay"
QT_MOC_LITERAL(1, 19, 17), // "highlightTerminal"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 9), // "Terminal*"
QT_MOC_LITERAL(4, 48, 8), // "terminal"
QT_MOC_LITERAL(5, 57, 10), // "persistent"
QT_MOC_LITERAL(6, 68, 23), // "removeTerminalHighlight"
QT_MOC_LITERAL(7, 92, 28), // "indicateKeyboardInputBlocked"
QT_MOC_LITERAL(8, 121, 13), // "terminalEvent"
QT_MOC_LITERAL(9, 135, 20), // "EventRect::EventType"
QT_MOC_LITERAL(10, 156, 4), // "type"
QT_MOC_LITERAL(11, 161, 21), // "EventRect::EventFlags"
QT_MOC_LITERAL(12, 183, 5), // "flags"
QT_MOC_LITERAL(13, 189, 14) // "cleanupOverlay"

    },
    "VisualEventOverlay\0highlightTerminal\0"
    "\0Terminal*\0terminal\0persistent\0"
    "removeTerminalHighlight\0"
    "indicateKeyboardInputBlocked\0terminalEvent\0"
    "EventRect::EventType\0type\0"
    "EventRect::EventFlags\0flags\0cleanupOverlay"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_VisualEventOverlay[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   49,    2, 0x0a /* Public */,
       1,    1,   54,    2, 0x2a /* Public | MethodCloned */,
       6,    0,   57,    2, 0x0a /* Public */,
       7,    1,   58,    2, 0x0a /* Public */,
       8,    3,   61,    2, 0x0a /* Public */,
       8,    2,   68,    2, 0x2a /* Public | MethodCloned */,
      13,    0,   73,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,    5,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 9, 0x80000000 | 11,    4,   10,   12,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 9,    4,   10,
    QMetaType::Void,

       0        // eod
};

void VisualEventOverlay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        VisualEventOverlay *_t = static_cast<VisualEventOverlay *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->highlightTerminal((*reinterpret_cast< Terminal*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 1: _t->highlightTerminal((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 2: _t->removeTerminalHighlight(); break;
        case 3: _t->indicateKeyboardInputBlocked((*reinterpret_cast< Terminal*(*)>(_a[1]))); break;
        case 4: _t->terminalEvent((*reinterpret_cast< Terminal*(*)>(_a[1])),(*reinterpret_cast< EventRect::EventType(*)>(_a[2])),(*reinterpret_cast< EventRect::EventFlags(*)>(_a[3]))); break;
        case 5: _t->terminalEvent((*reinterpret_cast< Terminal*(*)>(_a[1])),(*reinterpret_cast< EventRect::EventType(*)>(_a[2]))); break;
        case 6: _t->cleanupOverlay(); break;
        default: ;
        }
    }
}

const QMetaObject VisualEventOverlay::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_VisualEventOverlay.data,
      qt_meta_data_VisualEventOverlay,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *VisualEventOverlay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VisualEventOverlay::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_VisualEventOverlay.stringdata0))
        return static_cast<void*>(const_cast< VisualEventOverlay*>(this));
    return QWidget::qt_metacast(_clname);
}

int VisualEventOverlay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
